from random import randint
def печать (текст, стиль="", красный=False, зелёный=False,рандомный=False, жёлтый=False, синий=False, золотой=False, фиолетовый=False, не_печатать=False):
    def определить_стиль(стиль: str):
        стиль = стиль.lower()
        результат = ""
        if "ж" in стиль:
            результат += ";1"
        if "к" in стиль:
            результат += ";3"
        if "ч" in стиль:
            результат += ";4"
        if "з" in стиль:
            результат += ";9"
        return результат

    итоговый_стиль = определить_стиль(стиль)
    if красный:
        цвет = "255;0;0"
    elif зелёный:
        цвет = "0;255;0"
    elif синий:
        цвет = "0;0;255"
    elif рандомный:
        результат = ""
        for буква in текст:
            К = randint(0, 255)
            З = randint(0, 255)
            С = randint(0, 255)
            результат += f"\x1B[38;2;{К};{З};{С}{итоговый_стиль}m{буква}"
        результат += "\x1B[0m" 
#    результат = f"\x1B[38;2;{цвет};1m{текст}\x1B[0m"
        print(результат)
        return
    else:
        цвет = "255;255;255"
    результат = f"\x1B[38;2;{цвет}{итоговый_стиль}m{текст}\x1B[0m"
    if не_печатать:
        return результат
    print(результат)
    # \x1B[ - особый символ, который включает режим другого цвета
    # 38;2; - говорит о том, что следующие 3 команды будут в форме RGB
    # после цвета ;1 - особый стиль 
    # \x1B[0m - всё, что будет написано после этого символа будет стандартным цветом. Если не будет этой строчки, то все последующие print  будут печататься тем же цветом.

if __name__ == "__main__":
#    печать("Этот текст был вызван внутри файла", красный=True, стиль="жчз")
#    печать("Этот текст был вызван внутри файла", красный=True, стиль="ж")
#    печать("Этот текст был вызван внутри файла", красный=True, стиль="ч")
#    печать("Этот текст был вызван внутри файла", красный=True, стиль="з")
#    печать("Этот текст был вызван внутри файла", красный=True, стиль="к")
#    print("это обычный белый цвет")
    красный = печать("красный текст", красный=True, не_печатать=True)
    зелёный = печать("зелёный текст", зелёный=True, не_печатать=True)
    print(f"{красный} и {зелёный} текст в одной строке")
