from setuptools import setup
setup(
    name="xanter", # имя модуля, которое будет исполшьзоваться при установке через pip unstall
    version="0.3", # версия модуля, при каждом обновлении её надо увеличивать
    description="Мои личные инструменты", # в описании проекта, его можно не использовать
    packages=["xanter"], # список с названиями папок, которые нужно залить
    author_email="ulianaantonova651@gmail.com", # почта автора
    zip_safe=False, # пароль, можно не указывать
    install_requires = [], # список доп. модулей, которые необходимы для использования вашего модуля
)